@@ -5,7 +5,7 @@ import (
 	"oh-my-posh/color"
 	"oh-my-posh/console"
 	"oh-my-posh/engine"
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/shell"
 	"time"
 
@@ -20,11 +20,13 @@ var debugCmd = &cobra.Command{
 	Args:  cobra.NoArgs,
 	Run: func(cmd *cobra.Command, args []string) {
 		startTime := time.Now()
-		env := &environment.ShellEnvironment{
+		env := &platform.Shell{
 			Version: cliVersion,
-			CmdFlags: &environment.Flags{
+			CmdFlags: &platform.Flags{
 				Config: config,
 				Debug:  true,
+				PWD:    pwd,
+				Shell:  shellName,
 			},
 		}
 		env.Init()
@@ -56,5 +58,7 @@ var debugCmd = &cobra.Command{
 }
 
 func init() { //nolint:gochecknoinits
-	rootCmd.AddCommand(debugCmd)
+	debugCmd.Flags().StringVar(&pwd, "pwd", "", "current working directory")
+	debugCmd.Flags().StringVar(&shellName, "shell", "", "the shell to print for")
+	RootCmd.AddCommand(debugCmd)
 }
