@@ -2,8 +2,8 @@ package segments
 
 import (
 	"oh-my-posh/constants"
-	"oh-my-posh/environment"
 	"oh-my-posh/mock"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 	"testing"
 
@@ -29,7 +29,7 @@ func TestDotnetSegment(t *testing.T) {
 		env := new(mock.MockedEnvironment)
 		env.On("HasCommand", "dotnet").Return(tc.HasCommand)
 		if tc.ExitCode != 0 {
-			err := &environment.CommandError{ExitCode: tc.ExitCode}
+			err := &platform.CommandError{ExitCode: tc.ExitCode}
 			env.On("RunCommand", "dotnet", []string{"--version"}).Return("", err)
 		} else {
 			env.On("RunCommand", "dotnet", []string{"--version"}).Return(tc.Version, nil)
@@ -39,7 +39,7 @@ func TestDotnetSegment(t *testing.T) {
 		env.On("PathSeparator").Return("")
 		env.On("Pwd").Return("/usr/home/project")
 		env.On("Home").Return("/usr/home")
-		env.On("TemplateCache").Return(&environment.TemplateCache{
+		env.On("TemplateCache").Return(&platform.TemplateCache{
 			Env: make(map[string]string),
 		})
 		props := properties.Map{
