@@ -2,7 +2,7 @@ package segments
 
 import (
 	"fmt"
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 )
 
@@ -14,7 +14,7 @@ func (j *Java) Template() string {
 	return languageTemplate
 }
 
-func (j *Java) Init(props properties.Properties, env environment.Environment) {
+func (j *Java) Init(props properties.Properties, env platform.Environment) {
 	javaRegex := `(?: JRE)(?: \(.*\))? \((?P<version>(?P<major>[0-9]+)(?:\.(?P<minor>[0-9]+))?(?:\.(?P<patch>[0-9]+))?).*\),`
 	javaCmd := &cmd{
 		executable: "java",
