@@ -1,7 +1,7 @@
 package segments
 
 import (
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 )
 
@@ -17,7 +17,7 @@ func (n *Npm) Template() string {
 	return " \ue71e {{.Full}} "
 }
 
-func (n *Npm) Init(props properties.Properties, env environment.Environment) {
+func (n *Npm) Init(props properties.Properties, env platform.Environment) {
 	n.language = language{
 		env:        env,
 		props:      props,
