@@ -3,7 +3,7 @@ package segments
 import (
 	"encoding/json"
 	"fmt"
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 	"path/filepath"
 )
@@ -16,7 +16,7 @@ func (a *Nx) Template() string {
 	return languageTemplate
 }
 
-func (a *Nx) Init(props properties.Properties, env environment.Environment) {
+func (a *Nx) Init(props properties.Properties, env platform.Environment) {
 	a.language = language{
 		env:        env,
 		props:      props,
@@ -39,7 +39,7 @@ func (a *Nx) getVersion() (string, error) {
 	return getNodePackageVersion(a.language.env, "nx")
 }
 
-func getNodePackageVersion(env environment.Environment, nodePackage string) (string, error) {
+func getNodePackageVersion(env platform.Environment, nodePackage string) (string, error) {
 	const fileName string = "package.json"
 	folder := filepath.Join(env.Pwd(), "node_modules", nodePackage)
 	if !env.HasFilesInDir(folder, fileName) {
