@@ -1,7 +1,7 @@
 package segments
 
 import (
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 )
 
@@ -13,7 +13,7 @@ func (p *Perl) Template() string {
 	return languageTemplate
 }
 
-func (p *Perl) Init(props properties.Properties, env environment.Environment) {
+func (p *Perl) Init(props properties.Properties, env platform.Environment) {
 	perlRegex := `This is perl.*v(?P<version>(?P<major>[0-9]+)(?:\.(?P<minor>[0-9]+))(?:\.(?P<patch>[0-9]+))?).* built for .+`
 	p.language = language{
 		env:   env,
