@@ -1,13 +1,13 @@
 package segments
 
 import (
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 )
 
 type Root struct {
 	props properties.Properties
-	env   environment.Environment
+	env   platform.Environment
 }
 
 func (rt *Root) Template() string {
@@ -18,7 +18,7 @@ func (rt *Root) Enabled() bool {
 	return rt.env.Root()
 }
 
-func (rt *Root) Init(props properties.Properties, env environment.Environment) {
+func (rt *Root) Init(props properties.Properties, env platform.Environment) {
 	rt.props = props
 	rt.env = env
 }
