@@ -1,14 +1,14 @@
 package segments
 
 import (
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 	"strings"
 )
 
 type Shell struct {
 	props properties.Properties
-	env   environment.Environment
+	env   platform.Environment
 
 	Name    string
 	Version string
@@ -36,7 +36,7 @@ func (s *Shell) Enabled() bool {
 	return true
 }
 
-func (s *Shell) Init(props properties.Properties, env environment.Environment) {
+func (s *Shell) Init(props properties.Properties, env platform.Environment) {
 	s.props = props
 	s.env = env
 }
