@@ -1,13 +1,13 @@
 package segments
 
 import (
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 )
 
 type Text struct {
 	props properties.Properties
-	env   environment.Environment
+	env   platform.Environment
 }
 
 func (t *Text) Template() string {
@@ -18,7 +18,7 @@ func (t *Text) Enabled() bool {
 	return true
 }
 
-func (t *Text) Init(props properties.Properties, env environment.Environment) {
+func (t *Text) Init(props properties.Properties, env platform.Environment) {
 	t.props = props
 	t.env = env
 }
