@@ -1,14 +1,14 @@
 package segments
 
 import (
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 	"time"
 )
 
 type Time struct {
 	props properties.Properties
-	env   environment.Environment
+	env   platform.Environment
 
 	CurrentDate time.Time
 	Format      string
@@ -32,7 +32,7 @@ func (t *Time) Enabled() bool {
 	return true
 }
 
-func (t *Time) Init(props properties.Properties, env environment.Environment) {
+func (t *Time) Init(props properties.Properties, env platform.Environment) {
 	t.props = props
 	t.env = env
 }
