@@ -1,7 +1,7 @@
 package segments
 
 import (
-	"oh-my-posh/environment"
+	"oh-my-posh/platform"
 	"oh-my-posh/properties"
 )
 
@@ -16,7 +16,7 @@ func (u *UI5Tooling) Template() string {
 	return languageTemplate
 }
 
-func (u *UI5Tooling) Init(props properties.Properties, env environment.Environment) {
+func (u *UI5Tooling) Init(props properties.Properties, env platform.Environment) {
 	u.language = language{
 		env:         env,
 		props:       props,
