@@ -12,6 +12,8 @@ func funcMap() template.FuncMap {
 		"url":          url,
 		"path":         path,
 		"glob":         glob,
+		"matchP":       matchP,
+		"replaceP":     replaceP,
 	}
 	for key, fun := range sprig.TxtFuncMap() {
 		if _, ok := funcMap[key]; !ok {
