@@ -1,8 +1,8 @@
 package template
 
 import (
-	"oh-my-posh/environment"
 	"oh-my-posh/mock"
+	"oh-my-posh/platform"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -28,10 +28,11 @@ func TestRoundSeconds(t *testing.T) {
 	}
 
 	env := &mock.MockedEnvironment{}
-	env.On("TemplateCache").Return(&environment.TemplateCache{
+	env.On("TemplateCache").Return(&platform.TemplateCache{
 		Env: make(map[string]string),
 	})
-	env.On("Log", mock2.Anything, mock2.Anything, mock2.Anything)
+	env.On("Error", mock2.Anything, mock2.Anything)
+	env.On("Debug", mock2.Anything, mock2.Anything)
 	for _, tc := range cases {
 		tmpl := &Text{
 			Template: tc.Template,
