@@ -1,8 +1,8 @@
 package template
 
 import (
-	"oh-my-posh/environment"
 	"oh-my-posh/mock"
+	"oh-my-posh/platform"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -20,6 +20,11 @@ func TestRenderTemplate(t *testing.T) {
 		ShouldError bool
 		Context     interface{}
 	}{
+		{
+			Case:     "color override with dots",
+			Expected: "😺💬<#FF8000> Meow! What should I do next? ...</>",
+			Template: "😺💬<#FF8000> Meow! What should I do next? ...</>",
+		},
 		{
 			Case:     "tillig's regex",
 			Expected: " ⎈ hello :: world ",
@@ -144,10 +149,10 @@ func TestRenderTemplate(t *testing.T) {
 	}
 
 	env := &mock.MockedEnvironment{}
-	env.On("TemplateCache").Return(&environment.TemplateCache{
+	env.On("TemplateCache").Return(&platform.TemplateCache{
 		Env: make(map[string]string),
 	})
-	env.On("Log", mock2.Anything, mock2.Anything, mock2.Anything)
+	env.On("Error", mock2.Anything, mock2.Anything)
 	for _, tc := range cases {
 		tmpl := &Text{
 			Template: tc.Template,
@@ -201,10 +206,10 @@ func TestRenderTemplateEnvVar(t *testing.T) {
 	}
 	for _, tc := range cases {
 		env := &mock.MockedEnvironment{}
-		env.On("TemplateCache").Return(&environment.TemplateCache{
+		env.On("TemplateCache").Return(&platform.TemplateCache{
 			Env: tc.Env,
 		})
-		env.On("Log", mock2.Anything, mock2.Anything, mock2.Anything)
+		env.On("Error", mock2.Anything, mock2.Anything)
 		tmpl := &Text{
 			Template: tc.Template,
 			Context:  tc.Context,
@@ -279,3 +284,31 @@ func TestCleanTemplate(t *testing.T) {
 		assert.Equal(t, tc.Expected, tmpl.Template, tc.Case)
 	}
 }
+
+func TestSegmentContains(t *testing.T) {
+	cases := []struct {
+		Case     string
+		Expected string
+		Template string
+	}{
+		{Case: "match", Expected: "hello", Template: `{{ if .Segments.Contains "Git" }}hello{{ end }}`},
+		{Case: "match", Expected: "world", Template: `{{ if .Segments.Contains "Path" }}hello{{ else }}world{{ end }}`},
+	}
+
+	env := &mock.MockedEnvironment{}
+	env.On("TemplateCache").Return(&platform.TemplateCache{
+		Env: make(map[string]string),
+		Segments: map[string]interface{}{
+			"Git": nil,
+		},
+	})
+	for _, tc := range cases {
+		tmpl := &Text{
+			Template: tc.Template,
+			Context:  nil,
+			Env:      env,
+		}
+		text, _ := tmpl.Render()
+		assert.Equal(t, tc.Expected, text, tc.Case)
+	}
+}
